/********************************************************************************************************
Macro Name:   simBin.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     This program simulates multiple studies from the relevant binomial design. 
**** Needed Macro Variables;
    (1) pi_t        = <double> probability of failure in treatment group
    (2) nt          = <integer> number of subjects in treatment group
    (3) pi_c        = <double> probability of failure in control group
    (4) nc          = <integer> number of subjects in control group
    (5) studyRepNum = <integer> number of studies to simulate
    (6) dsOut       = <libname.dataset> dataset containing all simulation studies
*********************************************************************************************************/

%macro simBin(pi_t,nt,pi_c,nc,studyRepNum=100,dsOut=simStudy);
 proc IML;
  
  studyRepNum = &studyRepNum.;
  pi          = {&pi_t. &pi_c.};
  nGrp        = {&nt. &nc.};


  Y = J(studyRepNum,2,0);
  N = J(studyRepNum,1,nGrp[1])||J(studyRepNum,1,nGrp[2]);
  call randgen(Y,'binomial',pi,nGrp);



  Z = t(do(1,studyRepNum,1));
  pi = repeat(pi,studyRepNum,1);

  dat = Z||pi||Y||N;

  create &dsOut. from dat[c={"studyRep" "pi_t" "pi_c" "Yt" "Yc" "Nt" "Nc"}];
   append from dat;
  close &dsOut.;


 quit;

%mend;